name = "fissa"
path = name
version = "1.0.0"
author = "Sander Keemink and Scott Lowe"
author_email = "swkeemink@scimail.eu"
description = "A Python Library estimating somatic signals in 2-photon data"
url = "https://github.com/rochefort-lab/fissa"
